==> mobile_pos-0.6.0.tar.gz: android/src/main/java/com/raven/mobile_pos/MobilePosPlugin.java <==
package com.raven.mobile_pos;

import android.Manifest;
import android.app.Activity;
import android.bluetooth.BluetoothAdapter;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.graphics.SurfaceTexture;
import android.location.LocationManager;
import android.os.Build;
import android.view.Surface;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.annotation.RequiresApi;
import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;

import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;
import com.ravenpos.ravendspreadpos.RavenPosCallback;
import com.ravenpos.ravendspreadpos.StartRavenMobilePos;
import com.ravenpos.ravendspreadpos.model.BluetoothModel;
import com.ravenpos.ravendspreadpos.model.MobilePosDataModel;
import com.ravenpos.ravendspreadpos.model.MobilePosHelper;

import java.util.HashMap;
import java.util.List;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.view.TextureRegistry;


/** BvnSelfiePlugin */
public class MobilePosPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware, PluginRegistry.RequestPermissionsResultListener {
    private MethodChannel channel;
    private Activity flutterActivity;

    private Context context;
    private FlutterPluginBinding flutterBinding;

    private RavenPosCallback posCallback;

    private static final int BLUETOOTH_CODE = 100;

    private static final int LOCATION_CODE = 101;


    public StartRavenMobilePos ravenMobilePosIntance;

    private  String ravenBaseUrl="";

    MobilePosDataModel mobilePosPaymentData;

    private String[] locationPermissionList = new String[]{android.Manifest.permission.ACCESS_COARSE_LOCATION, android.Manifest.permission.ACCESS_FINE_LOCATION};

    private String[] bluethoothPermissionList = Build.VERSION.SDK_INT >= Build.VERSION_CODES.S ?
            new String[]{android.Manifest.permission.BLUETOOTH_SCAN, android.Manifest.permission.BLUETOOTH_CONNECT, Manifest.permission.BLUETOOTH_ADVERTISE}
            : new String[]{Manifest.permission.BLUETOOTH};

    BluetoothAdapter adapter = BluetoothAdapter.getDefaultAdapter();


    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {

        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "mobile_pos");
        flutterBinding=flutterPluginBinding;
        channel.setMethodCallHandler(this);
    }

    @RequiresApi(api = Build.VERSION_CODES.LOLLIPOP)
    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {

        if(call.method.equals(MobilePosConst.onPosSdkStatus)){
            initializeSdkProcess();
            result.success(true);
            return;
        }

        if(call.method.equals(MobilePosConst.onSetBaseUrl)){
            ravenBaseUrl= call.argument("base_url");
            result.success(true);
            return;
        }

        if(call.method.equals(MobilePosConst.onPosStartTransaction)){
            mobilePosPaymentData=new MobilePosDataModel(
                    call.argument("amount").toString(),
                    call.argument("account_type").toString(),
                    call.argument("terminal_id").toString(),
                    true,
                    call.argument("master_key").toString(),
                    call.argument("pin_key").toString(),
                    call.argument("port").toString(),
                    call.argument("ip").toString(),
                    call.argument("mid").toString(),
                    call.argument("serial_number").toString(),
                    call.argument("business_name").toString(),
                    call.argument("session_key").toString(),
                    ravenBaseUrl);
            initializeSdkProcess();

            result.success("PAYMENT INITIATED SUCCESSFULLY");
            return;
        }
        if(call.method.equals(MobilePosConst.disconnectDevice)){
            if(ravenMobilePosIntance==null){
                return;
            }
            ravenMobilePosIntance.disConnectDevice();
            ravenMobilePosIntance.destroyInstance();
            return;
        }
        if(call.method.equals(MobilePosConst.scanForMPosDevice)){
            if(ravenMobilePosIntance==null){
                return;
            }
            ravenMobilePosIntance.scanDevice();
            return;
        }

        if(call.method.equals(MobilePosConst.onRequestBluetoothConnection)){
            String address=call.argument("address");
            String deviceName=call.argument("title");
            int cardInjection=call.argument("card_injection");
            String serialNo=call.argument("serialNo");
            BluetoothModel model=new BluetoothModel(address,deviceName,0,serialNo,cardInjection);
            ravenMobilePosIntance.connectBluetoothDevice(model);
           return;
        }
        if(call.method.equals(MobilePosConst.onPinProvided)){
            if(ravenMobilePosIntance==null){
                return;
            }
            ravenMobilePosIntance.enterCardPin(call.argument("pin"));
            return;
        }
         result.notImplemented();
        return;
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        flutterActivity= binding.getActivity();
        context=flutterActivity.getApplicationContext();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
        flutterActivity= binding.getActivity();
        context=flutterActivity.getApplicationContext();
    }

    @Override
    public void onDetachedFromActivity(){
    }

    @Override
    public boolean onRequestPermissionsResult(int requestCode, @NonNull String[] permissions, @NonNull int[] grantResults) {
        if(requestCode==LOCATION_CODE&&grantResults.length>0){
            for(int x=0; x<grantResults.length; x++){
                if(grantResults[x]!=PackageManager.PERMISSION_GRANTED){
                    Toast.makeText(context,"Permission Not Yet Granted.",Toast.LENGTH_LONG).show();
                    return false;
                }
            }
            initializeSdkProcess();

        }
        if(requestCode==BLUETOOTH_CODE&&grantResults.length>0){
            for(int x=0; x<grantResults.length; x++){
                if(grantResults[x]!=PackageManager.PERMISSION_GRANTED){
                    Toast.makeText(context,"Permission Not Yet Granted.",Toast.LENGTH_LONG).show();
                    return false;
                }
            }

            initializeSdkProcess();
            return  true;
        }
        return false;
    }


    public void initializeSdkProcess() {
        if (adapter != null && !adapter.isEnabled()) {
            //if bluetooth is disabled, add one fix
            Intent enabler = new Intent(BluetoothAdapter.ACTION_REQUEST_ENABLE);
            if (ActivityCompat.checkSelfPermission(context, Manifest.permission.BLUETOOTH_CONNECT) != PackageManager.PERMISSION_GRANTED) {
            }
            flutterActivity.startActivity(enabler);

        }

        if (checkLocationStatus()) {
            if(requestLocationPermission()){
                if(requestBluetoothPermission()){
                    startTransaction();
                    return ;
                }
                Toast.makeText(context,"please accepted bluetooth connection permission",Toast.LENGTH_LONG).show();
                return;
            }

            Toast.makeText(context,"please accepted location permission",Toast.LENGTH_LONG).show();
        }
    }


    private boolean checkLocationStatus() {
        LocationManager lm = null;
        if (android.os.Build.VERSION.SDK_INT >= android.os.Build.VERSION_CODES.M) {
            lm = (LocationManager) context.getSystemService(Context.LOCATION_SERVICE);
        }
        return lm.isProviderEnabled(LocationManager.GPS_PROVIDER);
    }

    public boolean requestLocationPermission() {
        if (ContextCompat.checkSelfPermission(context, Manifest.permission.ACCESS_FINE_LOCATION) != PackageManager.PERMISSION_GRANTED
                || ContextCompat.checkSelfPermission(context, Manifest.permission.ACCESS_COARSE_LOCATION) != PackageManager.PERMISSION_GRANTED) {
            ActivityCompat.requestPermissions(flutterActivity, locationPermissionList, LOCATION_CODE);
        } else {
            return true;
        }
        return false;
    }

    public boolean requestBluetoothPermission() {
        if (Build.VERSION.SDK_INT >=Build.VERSION_CODES.S&&(ContextCompat.checkSelfPermission(context, android.Manifest.permission.BLUETOOTH_SCAN) != PackageManager.PERMISSION_GRANTED
                || ContextCompat.checkSelfPermission(context, android.Manifest.permission.BLUETOOTH_CONNECT) != PackageManager.PERMISSION_GRANTED
                || ContextCompat.checkSelfPermission(context, android.Manifest.permission.BLUETOOTH_ADVERTISE) != PackageManager.PERMISSION_GRANTED)) {
            ActivityCompat.requestPermissions(flutterActivity, bluethoothPermissionList, BLUETOOTH_CODE);
        } else {
            return true;
        }

        return false;
    }


    public void startTransaction(){
        if(mobilePosPaymentData==null){
            return;
        }
        posCallback=new RavenPosCallback() {
            @Override
            public void alertCallback(String message) {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("ALERT CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                HashMap<String, Object>  data=new HashMap<>();
                data.put("alert",message);
                channel.invokeMethod(MobilePosConst.onAlert,data);
            }

            @Override
            public void onErrorCallback(String error) {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("ERROR CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                HashMap<String, Object>  data=new HashMap<>();
                data.put("alert",error);
                channel.invokeMethod(MobilePosConst.onError,data);
            }

            @Override
            public void onBluetoothDeviceDetected(BluetoothModel model) {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("BLUETOOTH DEVICE DETECTED  CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                Gson gson = new Gson();
                String data=  gson.toJson(model);
                channel.invokeMethod(MobilePosConst.onBluetoothDeviceDetected,data);
            }

            @Override
            public void onBlutoothConnected() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("BLUETOOTH CONNECTED SUCCESSFULLY CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onBluetoothConnected,true);
            }

            @Override
            public void onFinishSettingBankBox() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("ON FINISHED SETTING BANKBOX CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onFinishedSettingBankBox,true);
            }

            @Override
            public void onBluetoothDisconnected() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("BLUETOOTH DISCONNECTED CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onBluetoothDisconnected,true);
            }

            @Override
            public void onBlutoothConnectionError() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("ON BLUETOOTH CONNECTION ERROR");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onBluetoothConnectionError,true);
            }

            @Override
            public void onNoDeviceDetected() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("NO DEVICE DETECETED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.noDeviceDetectedAnymore,true);
            }

            @Override
            public void bluethootStartScaning() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("BLUETOOTH START SCANNING CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onBluetoothStartScanning,true);
            }

            @Override
            public void bluethootStopScaning() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("BLUETOOTH STOP SCANNING CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onBluetoothStopScanning,true);
            }

            @Override
            public void onRequestPin() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("REQUEST PIN CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onRequestPin,true);
            }

            @Override
            public void onRequestInsertCard() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("REQUEST CARD CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onRequestCard,true);
            }

            @Override
            public void onSettingBankBox() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("ON SETTING BANKBOX CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onSettingBankBox,true);
            }

            @Override
            public void onTransactionError(String s) {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("TRANSACTION ERROR CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onTransactionError,true);
            }

            @Override
            public void ontransactionCompleted(String transactionPayload) {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("TRANSACTION COMPLETED CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onProcessCardPayment,transactionPayload);
            }
        };
        ravenMobilePosIntance=new StartRavenMobilePos(posCallback,mobilePosPaymentData,context,flutterActivity);
        ravenMobilePosIntance.scanDevice();

    }



}

==> mobile_pos-0.7.0.tar.gz: android/src/main/java/com/raven/mobile_pos/MobilePosPlugin.java <==
package com.raven.mobile_pos;

import android.Manifest;
import android.app.Activity;
import android.bluetooth.BluetoothAdapter;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.graphics.SurfaceTexture;
import android.location.LocationManager;
import android.os.Build;
import android.view.Surface;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.annotation.RequiresApi;
import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;

import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;
import com.ravenpos.ravendspreadpos.RavenPosCallback;
import com.ravenpos.ravendspreadpos.StartRavenMobilePos;
import com.ravenpos.ravendspreadpos.model.BluetoothModel;
import com.ravenpos.ravendspreadpos.model.MobilePosDataModel;
import com.ravenpos.ravendspreadpos.model.MobilePosHelper;

import java.util.HashMap;
import java.util.List;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.view.TextureRegistry;


/** BvnSelfiePlugin */
public class MobilePosPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware, PluginRegistry.RequestPermissionsResultListener {
    private MethodChannel channel;
    private Activity flutterActivity;

    private Context context;
    private FlutterPluginBinding flutterBinding;

    private RavenPosCallback posCallback;

    private static final int BLUETOOTH_CODE = 100;

    private static final int LOCATION_CODE = 101;


    public StartRavenMobilePos ravenMobilePosIntance;

    private  String ravenBaseUrl="";

    private Result pluginResult;

    MobilePosDataModel mobilePosPaymentData;

    private String[] locationPermissionList = new String[]{android.Manifest.permission.ACCESS_COARSE_LOCATION, android.Manifest.permission.ACCESS_FINE_LOCATION};

    private String[] bluethoothPermissionList = Build.VERSION.SDK_INT >= Build.VERSION_CODES.S ?
            new String[]{android.Manifest.permission.BLUETOOTH_SCAN, android.Manifest.permission.BLUETOOTH_CONNECT, Manifest.permission.BLUETOOTH_ADVERTISE}
            : new String[]{Manifest.permission.BLUETOOTH};

    BluetoothAdapter adapter = BluetoothAdapter.getDefaultAdapter();


    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {

        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "mobile_pos");
        flutterBinding=flutterPluginBinding;
        channel.setMethodCallHandler(this);

    }

    @RequiresApi(api = Build.VERSION_CODES.LOLLIPOP)
    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {

         pluginResult=result;
        if(call.method.equals(MobilePosConst.onPosSdkStatus)){
            initializeSdkProcess();
            result.success(true);
            return;
        }

        if(call.method.equals(MobilePosConst.onSetBaseUrl)){
            ravenBaseUrl= call.argument("base_url");
            result.success(true);
            return;
        }

        if(call.method.equals(MobilePosConst.onPosStartTransaction)){
            mobilePosPaymentData=new MobilePosDataModel(
                    call.argument("amount").toString(),
                    call.argument("account_type").toString(),
                    call.argument("terminal_id").toString(),
                    true,
                    call.argument("master_key").toString(),
                    call.argument("pin_key").toString(),
                    call.argument("port").toString(),
                    call.argument("ip").toString(),
                    call.argument("mid").toString(),
                    call.argument("serial_number").toString(),
                    call.argument("business_name").toString(),
                    call.argument("session_key").toString(),
                    ravenBaseUrl);
            initializeSdkProcess();

            result.success("PAYMENT INITIATED SUCCESSFULLY");
            return;
        }
        if(call.method.equals(MobilePosConst.disconnectDevice)){
            if(ravenMobilePosIntance==null){
                return;
            }
            return;
        }
        if(call.method.equals(MobilePosConst.scanForMPosDevice)){
            if(ravenMobilePosIntance==null){
                return;
            }
            ravenMobilePosIntance.scanDevice();
            return;
        }
        if(call.method.equals(MobilePosConst.cancelPinEntry)){
            if(ravenMobilePosIntance==null){
                return;
            }
            ravenMobilePosIntance.cancelPinEntry();
            return;
        }

        if(call.method.equals(MobilePosConst.onRequestBluetoothConnection)){
            String address=call.argument("address");
            String deviceName=call.argument("title");
            int cardInjection=call.argument("card_injection");
            String serialNo=call.argument("serialNo");
            BluetoothModel model=new BluetoothModel(address,deviceName,0,serialNo,cardInjection);
            ravenMobilePosIntance.connectBluetoothDevice(model);
           return;
        }
        if(call.method.equals(MobilePosConst.onPinProvided)){
            if(ravenMobilePosIntance==null){
                return;
            }
            ravenMobilePosIntance.enterCardPin(call.argument("pin"));
            return;
        }

        if(call.method.equals(MobilePosConst.disconnectDeviceFROMPOS)){
            if(ravenMobilePosIntance==null){
                return;
            }

            ravenMobilePosIntance.disConnectDevice();
            ravenMobilePosIntance=null;
            return;
        }
         result.notImplemented();
        return;
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        flutterActivity= binding.getActivity();
        context=flutterActivity.getApplicationContext();
        binding.addRequestPermissionsResultListener(this);
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
        flutterActivity= binding.getActivity();
        context=flutterActivity.getApplicationContext();
    }

    @Override
    public void onDetachedFromActivity(){
    }

    @Override
    public boolean onRequestPermissionsResult(int requestCode, @NonNull String[] permissions, @NonNull int[] grantResults) {
        if(requestCode==LOCATION_CODE&&grantResults.length>0){
            for(int x=0; x<grantResults.length; x++){
                if(grantResults[x]!=PackageManager.PERMISSION_GRANTED){
                    Toast.makeText(context,"Permission Not Yet Granted.",Toast.LENGTH_LONG).show();
                    return false;
                }
            }
            initializeSdkProcess();

        }
        if(requestCode==BLUETOOTH_CODE&&grantResults.length>0){
            for(int x=0; x<grantResults.length; x++){
                if(grantResults[x]!=PackageManager.PERMISSION_GRANTED){
                    Toast.makeText(context,"Permission Not Yet Granted.",Toast.LENGTH_LONG).show();
                    return false;
                }
            }

            initializeSdkProcess();
            return  true;
        }
        return false;
    }


    public void initializeSdkProcess() {

        if (adapter != null && !adapter.isEnabled()) {
            //if bluetooth is disabled, add one fix
            Intent enabler = new Intent(BluetoothAdapter.ACTION_REQUEST_ENABLE);
            if (ActivityCompat.checkSelfPermission(context, Manifest.permission.BLUETOOTH_CONNECT) != PackageManager.PERMISSION_GRANTED) {
            }
            flutterActivity.startActivity(enabler);

        }

        if (checkLocationStatus()) {
            if(requestLocationPermission()){
                if(requestBluetoothPermission()){
                    startTransaction();
                    return ;
                }
                Toast.makeText(context,"please accepted bluetooth connection permission",Toast.LENGTH_LONG).show();
                return;
            }

            Toast.makeText(context,"please accepted location permission",Toast.LENGTH_LONG).show();
        }
    }


    private boolean checkLocationStatus() {
        LocationManager lm = null;
        if (android.os.Build.VERSION.SDK_INT >= android.os.Build.VERSION_CODES.M) {
            lm = (LocationManager) context.getSystemService(Context.LOCATION_SERVICE);
        }
        return lm.isProviderEnabled(LocationManager.GPS_PROVIDER);
    }

    public boolean requestLocationPermission() {
        if (ContextCompat.checkSelfPermission(context, Manifest.permission.ACCESS_FINE_LOCATION) != PackageManager.PERMISSION_GRANTED
                || ContextCompat.checkSelfPermission(context, Manifest.permission.ACCESS_COARSE_LOCATION) != PackageManager.PERMISSION_GRANTED) {
            ActivityCompat.requestPermissions(flutterActivity, locationPermissionList, LOCATION_CODE);
        } else {
            return true;
        }
        return false;
    }

    public boolean requestBluetoothPermission() {
        if (Build.VERSION.SDK_INT >=Build.VERSION_CODES.S&&(ContextCompat.checkSelfPermission(context, android.Manifest.permission.BLUETOOTH_SCAN) != PackageManager.PERMISSION_GRANTED
                || ContextCompat.checkSelfPermission(context, android.Manifest.permission.BLUETOOTH_CONNECT) != PackageManager.PERMISSION_GRANTED
                || ContextCompat.checkSelfPermission(context, android.Manifest.permission.BLUETOOTH_ADVERTISE) != PackageManager.PERMISSION_GRANTED)) {
            ActivityCompat.requestPermissions(flutterActivity, bluethoothPermissionList, BLUETOOTH_CODE);
        } else {
            return true;
        }

        return false;
    }


    public void startTransaction(){

        if(mobilePosPaymentData==null){
            return;
        }

        posCallback=new RavenPosCallback() {
            @Override
            public void alertCallback(String message) {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("ALERT CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                HashMap<String, Object>  data=new HashMap<>();
                data.put("alert",message);
                channel.invokeMethod(MobilePosConst.onAlert,data);
            }

            @Override
            public void onErrorCallback(String error) {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("ERROR CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                HashMap<String, Object>  data=new HashMap<>();
                data.put("alert",error);
                channel.invokeMethod(MobilePosConst.onError,data);
            }

            @Override
            public void onBluetoothDeviceDetected(BluetoothModel model) {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("BLUETOOTH DEVICE DETECTED  CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                Gson gson = new Gson();
                String data=  gson.toJson(model);
                channel.invokeMethod(MobilePosConst.onBluetoothDeviceDetected,data);
            }

            @Override
            public void onBlutoothConnected() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("BLUETOOTH CONNECTED SUCCESSFULLY CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onBluetoothConnected,true);
            }

            @Override
            public void onFinishSettingBankBox() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("ON FINISHED SETTING BANKBOX CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onFinishedSettingBankBox,true);
            }

            @Override
            public void onBluetoothDisconnected() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("BLUETOOTH DISCONNECTED CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onBluetoothDisconnected,true);
            }

            @Override
            public void onBlutoothConnectionError() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("ON BLUETOOTH CONNECTION ERROR");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onBluetoothConnectionError,true);
            }

            @Override
            public void onNoDeviceDetected() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("NO DEVICE DETECETED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.noDeviceDetectedAnymore,true);
            }

            @Override
            public void bluethootStartScaning() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("BLUETOOTH START SCANNING CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onBluetoothStartScanning,true);
            }

            @Override
            public void bluethootStopScaning() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("BLUETOOTH STOP SCANNING CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onBluetoothStopScanning,true);
            }

            @Override
            public void onRequestPin() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("REQUEST PIN CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onRequestPin,true);
            }

            @Override
            public void onRequestInsertCard() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("REQUEST CARD CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onRequestCard,true);
            }

            @Override
            public void onSettingBankBox() {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("ON SETTING BANKBOX CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onSettingBankBox,true);
            }

            @Override
            public void onTransactionError(String s) {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("TRANSACTION ERROR CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onTransactionError,true);
            }

            @Override
            public void ontransactionCompleted(String transactionPayload) {
                MobilePosHelper.logError("***********************");
                MobilePosHelper.logError("TRANSACTION COMPLETED CALLBACK TRIGGERED");
                MobilePosHelper.logError("***********************");
                channel.invokeMethod(MobilePosConst.onProcessCardPayment,transactionPayload);
            }
        };

        if(ravenMobilePosIntance!=null&&ravenMobilePosIntance.getBluetoothState()){
            ravenMobilePosIntance.ReInit(mobilePosPaymentData);
            ravenMobilePosIntance.resetTrade();
            if(pluginResult!=null){
                pluginResult.success("REINIT");
            }
            return;
        }

        ravenMobilePosIntance=new StartRavenMobilePos(posCallback,mobilePosPaymentData,context,flutterActivity);
         ravenMobilePosIntance.scanDevice();

    }
}
